==> jersey-mvc-freemarker-2.4.1-sources.jar: org/glassfish/jersey/server/mvc/freemarker/FreemarkerProperties.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.jersey.server.mvc.freemarker;

import org.glassfish.jersey.server.mvc.MvcProperties;

/**
 * Jersey MVC Freemarker configuration properties.
 *
 * @author Michal Gajdos (michal.gajdos at oracle.com)
 */
public final class FreemarkerProperties {

    /**
     * The base path where Freemarker templates, associated with {@link org.glassfish.jersey.server.mvc.Viewable viewables} of
     * resource classes, are located.
     * <p/>
     * If this property is not set then the base path will be the root path.
     */
    public final static String TEMPLATES_BASE_PATH = MvcProperties.TEMPLATE_BASE_PATH + ".freemarker";

    /**
     * Prevent initialization.
     */
    private FreemarkerProperties() {
    }
}

==> jersey-mvc-freemarker-2.5.1-sources.jar: org/glassfish/jersey/server/mvc/freemarker/FreemarkerProperties.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.jersey.server.mvc.freemarker;

/**
 * Jersey MVC Freemarker configuration properties.
 *
 * @author Michal Gajdos (michal.gajdos at oracle.com)
 * @deprecated Use properties from {@link org.glassfish.jersey.server.mvc.freemarker.FreemarkerMvcFeature} instead.
 */
@Deprecated
public final class FreemarkerProperties {

    /**
     * The base path where Freemarker templates, associated with {@link org.glassfish.jersey.server.mvc.Viewable viewables} of
     * resource classes, are located.
     * <p/>
     * If this property is not set then the base path will be the root path.
     */
    public final static String TEMPLATES_BASE_PATH = FreemarkerMvcFeature.TEMPLATES_BASE_PATH;

    /**
     * Prevent initialization.
     */
    private FreemarkerProperties() {
    }
}
